@@ -1,7 +1,7 @@
 from ._version import __version__
 from .builder import FmuBuilder
-from .enums import Fmi3Causality, Fmi3Initial, Fmi3Variability
-from .fmi3slave import Fmi3Slave
+from .enums import Fmi3Causality, Fmi3Initial, Fmi3Status, Fmi3Variability
+from .fmi3slave import Fmi3Slave, Fmi3StepResult
 from .variables import Boolean, Enumeration, Int32, Int64, UInt64, Float64, String, Dimension
 from .default_experiment import DefaultExperiment
 from .variable_types import Float64Type, EnumerationType
