@@ -8,7 +8,7 @@ from xml.etree import ElementTree
 
 from pythonfmu3 import Fmi3Slave
 from pythonfmu3.enums import Fmi3Causality, Fmi3Initial, Fmi3Variability
-from pythonfmu3.variables import Boolean, Integer, UInt64, Real, ModelVariable, String, Dimension
+from pythonfmu3.variables import Boolean, Int32, UInt64, Float64, ModelVariable, String, Dimension
 
 from .utils import PY2FMI, UInt64ValType
 
@@ -43,9 +43,9 @@ def test_ModelVariable_constructor(causality, initial, variability, name, descri
 
 @pytest.mark.parametrize("fmi_type,value", [
     (Boolean, False),
-    (Integer, 22),
+    (Int32, 22),
     (UInt64, UInt64ValType(23)),
-    (Real, 2./3.),
+    (Float64, 2./3.),
     (String, "hello_world"),
 ])
 def test_ModelVariable_getter(fmi_type, value):
@@ -68,9 +68,9 @@ def test_ModelVariable_getter(fmi_type, value):
 
 @pytest.mark.parametrize("fmi_type,value", [
     (Boolean, False),
-    (Integer, 22),
+    (Int32, 22),
     (UInt64, UInt64ValType(23)),
-    (Real, 2./3.),
+    (Float64, 2./3.),
     (String, "hello_world")
 ])
 def test_ModelVariable_setter(fmi_type, value):
@@ -100,8 +100,8 @@ def test_ModelVariable_setter(fmi_type, value):
 
 @pytest.mark.requirements("numpy")  
 @pytest.mark.parametrize("fmi_type,value,dims", [
-    (Real, [1.,2.,3.,4.], [4]),
-    (Real, [1.,2.,3.,4.], [2, 2]),
+    (Float64, [1.,2.,3.,4.], [4]),
+    (Float64, [1.,2.,3.,4.], [2, 2]),
 ])
 def test_ModelVariable_getter_array(fmi_type, value, dims):
 
@@ -124,8 +124,8 @@ def test_ModelVariable_getter_array(fmi_type, value, dims):
 
 @pytest.mark.requirements("numpy")  
 @pytest.mark.parametrize("fmi_type,value,dims", [
-    (Real, [1.,2.,3.,4.], [4]),
-    (Real, [1.,2.,3.,4.], [2, 2]),
+    (Float64, [1.,2.,3.,4.], [4]),
+    (Float64, [1.,2.,3.,4.], [2, 2]),
 ])
 def test_ModelVariable_setter_array(fmi_type, value, dims):
 
@@ -180,9 +180,9 @@ def test_ModelVariable_to_xml(causality, initial, variability, name, description
 
 @pytest.mark.parametrize("var_type, value", [
     (Boolean, True),
-    (Integer, 23),
+    (Int32, 23),
     (UInt64, UInt64ValType(23)),
-    (Real, 15.),
+    (Float64, 15.),
     (String, "hello")])
 @pytest.mark.parametrize("causality", list(Fmi3Causality) + [None])
 @pytest.mark.parametrize("initial", list(Fmi3Initial) + [None])
@@ -240,7 +240,7 @@ def test_Boolean_to_xml(name, start):
     ("integer_another_name", 42),
 ])
 def test_Integer_constructor(name, start):
-    r = Integer(name, start)
+    r = Int32(name, start)
 
     assert r.start == start
 
@@ -250,7 +250,7 @@ def test_Integer_constructor(name, start):
     ("integer_another_name", 42),
 ])
 def test_Integer_to_xml(name, start):
-    r = Integer(name, start)
+    r = Int32(name, start)
     xml = r.to_xml()
     if start is not None:
         assert xml.attrib['start'] == str(start)
@@ -261,7 +261,7 @@ def test_Integer_to_xml(name, start):
     ("real_another_name", 22.),
 ])
 def test_Real_constructor(name, start):
-    r = Real(name, start)
+    r = Float64(name, start)
 
     assert r.start == start
 
@@ -271,7 +271,7 @@ def test_Real_constructor(name, start):
     ("real_another_name", 22.),
 ])
 def test_Real_to_xml(name, start):
-    r = Real(name, start)
+    r = Float64(name, start)
     xml = r.to_xml()
     if start is not None:
         assert xml.attrib['start'] == f"{start:.16g}"
@@ -295,7 +295,9 @@ def test_String_to_xml(name, start):
     r = String(name, start)
     xml = r.to_xml()
     if start is not None:
-        assert xml.attrib['start'] == str(start)
+        start_elements = xml.findall('.//Start')
+        assert len(start_elements) == 1
+        assert start_elements[0].attrib['value'] == str(start)
 
 
 @pytest.mark.requirements("numpy")  
@@ -304,7 +306,7 @@ def test_String_to_xml(name, start):
     ("array2", [1.,2.,3.,4.], [2, 2]),
 ])
 def test_array_to_xml(name, start, dims):
-    r = Real(name, start, dimensions=[Dimension(start=val) for val in dims])
+    r = Float64(name, start, dimensions=[Dimension(start=val) for val in dims])
     xml = r.to_xml()
     if start is not None:
         assert xml.attrib['start'] == " ".join([f"{val:.16g}" for val in start])
